plone.app.event.at.content — plone.app.event 1.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »

# plone.app.event.at.content

class `plone.app.event.at.content.` `ATEvent`(oid, **kwargs)

  Information about an upcoming event, which can be displayed in the calendar.

  `Contributors`(**kw)

    Default Accessor.

  `Creators`(**kw)

    Default Accessor.

  `Description`(**kw)

    Default Accessor.

  `Language`(**kw)

    Default Accessor.

  `Rights`(**kw)

    Default Accessor.

  `Subject`(**kw)

    Default Accessor.

  `Title`(**kw)

    Default Accessor.

  `contact_email`(**kw)

    Default Accessor.

  `contact_name`(**kw)

    Default Accessor.

  `contact_phone`(**kw)

    Default Accessor.

  `duration`

    Return duration of the event as Python timedelta.

    Returns: | Duration of the event.
    Return type: | Python timedelta

  `end_date`

    Return end date as Python datetime.

    Please note, the end date marks only the end of an individual occurrence and not the end of a recurrence sequence.

    Returns: | End of the event.
    Return type: | Python datetime

  `event_url`(**kw)

    Default Accessor.

  `getAttendees`(**kw)

    Default Accessor.

  `getEffectiveDate`(**kw)

    Default Accessor.

  `getExcludeFromNav`(**kw)

    Default Accessor.

  `getExpirationDate`(**kw)

    Default Accessor.

  `getLocation`(**kw)

    Default Accessor.

  `getOpenEnd`(**kw)

    Default Accessor.

  `getRawAttendees`(**kw)

    Default Edit Accessor.

  `getRawContactEmail`(**kw)

    Default Edit Accessor.

  `getRawContactName`(**kw)

    Default Edit Accessor.

  `getRawContactPhone`(**kw)

    Default Edit Accessor.

  `getRawContributors`(**kw)

    Default Edit Accessor.

  `getRawCreation_date`(**kw)

    Default Edit Accessor.

  `getRawCreators`(**kw)

    Default Edit Accessor.

  `getRawDescription`(**kw)

    Default Edit Accessor.

  `getRawEffectiveDate`(**kw)

    Default Edit Accessor.

  `getRawEndDate`(**kw)

    Default Edit Accessor.

  `getRawEventUrl`(**kw)

    Default Edit Accessor.

  `getRawExcludeFromNav`(**kw)

    Default Edit Accessor.

  `getRawExpirationDate`(**kw)

    Default Edit Accessor.

  `getRawId`(**kw)

    Default Edit Accessor.

  `getRawLanguage`(**kw)

    Default Edit Accessor.

  `getRawLocation`(**kw)

    Default Edit Accessor.

  `getRawModification_date`(**kw)

    Default Edit Accessor.

  `getRawOpenEnd`(**kw)

    Default Edit Accessor.

  `getRawRecurrence`(**kw)

    Default Edit Accessor.

  `getRawRelatedItems`(**kw)

    Default Edit Accessor.

  `getRawRights`(**kw)

    Default Edit Accessor.

  `getRawStartDate`(**kw)

    Default Edit Accessor.

  `getRawSubject`(**kw)

    Default Edit Accessor.

  `getRawText`(**kw)

    Default Edit Accessor.

  `getRawTimezone`(**kw)

    Default Edit Accessor.

  `getRawTitle`(**kw)

    Default Edit Accessor.

  `getRawWholeDay`(**kw)

    Default Edit Accessor.

  `getRecurrence`(**kw)

    Default Accessor.

  `getRelatedItems`(**kw)

    Default Accessor.

  `getText`(**kw)

    Default Accessor.

  `getTimezone`(**kw)

    Default Accessor.

  `getWholeDay`(**kw)

    Default Accessor.

  `setAttendees`(value, **kw)

    Default Mutator.

  `setContactEmail`(value, **kw)

    Default Mutator.

  `setContactName`(value, **kw)

    Default Mutator.

  `setContactPhone`(value, **kw)

    Default Mutator.

  `setContributors`(value, **kw)

    Default Mutator.

  `setCreators`(value, **kw)

    Default Mutator.

  `setDescription`(value, **kw)

    Default Mutator.

  `setEffectiveDate`(value, **kw)

    Default Mutator.

  `setEventUrl`(value, **kw)

    Default Mutator.

  `setExcludeFromNav`(value, **kw)

    Default Mutator.

  `setExpirationDate`(value, **kw)

    Default Mutator.

  `setLanguage`(value, **kw)

    Default Mutator.

  `setLocation`(value, **kw)

    Default Mutator.

  `setOpenEnd`(value, **kw)

    Default Mutator.

  `setRecurrence`(value, **kw)

    Default Mutator.

  `setRelatedItems`(value, **kw)

    Default Mutator.

  `setRights`(value, **kw)

    Default Mutator.

  `setSubject`(value, **kw)

    Default Mutator.

  `setText`(value, **kw)

    Default Mutator.

  `setTitle`(value, **kw)

    Default Mutator.

  `setWholeDay`(value, **kw)

    Default Mutator.

  `start_date`

    Return start date as Python datetime.

    Returns: | Start of the event.
    Return type: | Python datetime

class `plone.app.event.at.content.` `EventAccessor`(context)

  Generic event accessor adapter implementation for Archetypes content objects.

class `plone.app.event.at.content.` `StartEndDateValidator`(context)

  Checks whether startDate is before endDate. In case the event is openEnded this check is skipped.

`plone.app.event.at.content.` `data_postprocessing`(obj, event)

  When setting the startDate and endDate, the value of the timezone field isn’t known, so we have to convert those timezone-naive dates into timezone-aware ones afterwards.

  For whole day events, set start time to 0:00:00 and end time to 23:59:59. For open end events, set end time to 23:59:59.

### Navigation

- index
- modules |
- next |
- previous |
- plone.app.event 1.0dev documentation »
- plone.app.event API »